==> net.bluemind.core.backup.continuous.mgmt.service-4.9.3879.jar: net/bluemind/core/backup/continuous/mgmt/service/containers/mail/RecordsSync.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2022
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.core.backup.continuous.mgmt.service.containers.mail;

import net.bluemind.backend.mail.replica.api.IDbMailboxRecords;
import net.bluemind.backend.mail.replica.api.IMailReplicaUids;
import net.bluemind.backend.mail.replica.api.MailboxRecord;
import net.bluemind.core.backup.continuous.mgmt.service.impl.ContainerSync;
import net.bluemind.core.backup.continuous.mgmt.service.impl.LoggedContainerDeltaSync;
import net.bluemind.core.container.api.ContainerHierarchyNode;
import net.bluemind.core.container.api.IContainers;
import net.bluemind.core.container.model.ContainerDescriptor;
import net.bluemind.core.container.model.ItemValue;
import net.bluemind.core.rest.BmContext;
import net.bluemind.directory.service.DirEntryAndValue;
import net.bluemind.domain.api.Domain;

public class RecordsSync<O> extends LoggedContainerDeltaSync<O, MailboxRecord> {

	public RecordsSync(BmContext ctx, ContainerDescriptor container, ItemValue<ContainerHierarchyNode> node,
			ItemValue<DirEntryAndValue<O>> owner, ItemValue<Domain> domain) {
		super(ctx, container, node, owner, domain);
	}

	public static class SyncFactory implements ContainerSync.Factory {

		@Override
		public <U> ContainerSync forNode(BmContext ctx, ItemValue<ContainerHierarchyNode> node,
				ItemValue<DirEntryAndValue<U>> owner, ItemValue<Domain> domain) {
			IContainers contApi = ctx.provider().instance(IContainers.class);
			ContainerDescriptor container = contApi.get(node.value.containerUid);
			return new RecordsSync<U>(ctx, container, node, owner, domain);
		}

	}

	@Override
	protected ReadApis<MailboxRecord> initReadApi() {
		IDbMailboxRecords recsApi = ctx.provider().instance(IDbMailboxRecords.class,
				IMailReplicaUids.getUniqueId(node.value.containerUid));
		return new ReadApis<>(recsApi, recsApi);
	}

}

==> net.bluemind.core.backup.continuous.mgmt.service-5.5.3184.jar: net/bluemind/core/backup/continuous/mgmt/service/containers/mail/RecordsSync.java <==
/* BEGIN LICENSE
 * Copyright © Blue Mind SAS, 2012-2022
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.core.backup.continuous.mgmt.service.containers.mail;

import java.util.concurrent.atomic.AtomicLong;

import net.bluemind.backend.mail.api.MailboxFolder;
import net.bluemind.backend.mail.api.MessageBody;
import net.bluemind.backend.mail.replica.api.IDbByContainerReplicatedMailboxes;
import net.bluemind.backend.mail.replica.api.IDbMailboxRecords;
import net.bluemind.backend.mail.replica.api.IMailReplicaUids;
import net.bluemind.backend.mail.replica.api.MailboxRecord;
import net.bluemind.core.backup.continuous.api.IBackupStoreFactory;
import net.bluemind.core.backup.continuous.mgmt.service.impl.ContainerSync;
import net.bluemind.core.backup.continuous.mgmt.service.impl.LoggedContainerDeltaSync;
import net.bluemind.core.container.api.ContainerHierarchyNode;
import net.bluemind.core.container.api.IContainers;
import net.bluemind.core.container.model.ContainerDescriptor;
import net.bluemind.core.container.model.ItemFlag;
import net.bluemind.core.container.model.ItemValue;
import net.bluemind.core.rest.BmContext;
import net.bluemind.core.task.service.IServerTaskMonitor;
import net.bluemind.directory.service.DirEntryAndValue;
import net.bluemind.domain.api.Domain;

public class RecordsSync<O> extends LoggedContainerDeltaSync<O, MailboxRecord> {

	public static record BodyStat(AtomicLong body, AtomicLong esSource) {

	}

	private BodyStat bodyStat;

	public RecordsSync(BmContext ctx, ContainerDescriptor container, ItemValue<ContainerHierarchyNode> node,
			ItemValue<DirEntryAndValue<O>> owner, ItemValue<Domain> domain) {
		super(ctx, container, node, owner, domain);
		this.bodyStat = new BodyStat(new AtomicLong(), new AtomicLong());
	}

	public static class SyncFactory implements ContainerSync.Factory {

		@Override
		public <U> ContainerSync forNode(BmContext ctx, ItemValue<ContainerHierarchyNode> node,
				ItemValue<DirEntryAndValue<U>> owner, ItemValue<Domain> domain) {
			IContainers contApi = ctx.provider().instance(IContainers.class);
			ContainerDescriptor container = contApi.get(node.value.containerUid);
			return new RecordsSync<U>(ctx, container, node, owner, domain);
		}

	}

	@Override
	protected ReadApis<MailboxRecord> initReadApi() {
		IDbMailboxRecords recsApi = ctx.provider().instance(IDbMailboxRecords.class,
				IMailReplicaUids.getUniqueId(node.value.containerUid));
		return new ReadApis<>(recsApi, recsApi);
	}

	@Override
	protected boolean skipContainer() {
		String subtree = IMailReplicaUids.subtreeUid(domain.uid, owner.value.entry);
		IDbByContainerReplicatedMailboxes parentFolders = ctx.provider()
				.instance(IDbByContainerReplicatedMailboxes.class, subtree);
		ItemValue<MailboxFolder> folderItem = parentFolders
				.getComplete(IMailReplicaUids.getUniqueId(node.value.containerUid));
		return folderItem.flags.contains(ItemFlag.Deleted);
	}

	@Override
	protected void preSync(IBackupStoreFactory target, IServerTaskMonitor entryMon, ItemValue<MailboxRecord> mr) {
		MessageBodySync syncMessageBody = new MessageBodySync(target, domain, entryMon, cont);
		MessageBody body = syncMessageBody.storeMessageBodies(bodyStat, mr);

		IndexedMessageBodySync indexedSyncMessageBody = new IndexedMessageBodySync(target, entryMon, domain, cont);
		indexedSyncMessageBody.storeIndexedMessageBodies(bodyStat, mr.value, body);
	}
}
